@@ -20,9 +20,7 @@
 
 #pragma once
 
-#include "spice-common.h"
 #include <stddef.h>
-#include <ucontext.h>
 #include <setjmp.h>
 
 struct continuation
@@ -33,9 +31,8 @@ struct continuation
 	int (*release)(struct continuation *cc);
 
 	/* private */
-	ucontext_t uc;
-	ucontext_t last;
 	int exited;
+	void *last;
 	jmp_buf jmp;
 };
 
@@ -47,11 +44,6 @@ int cc_release(struct continuation *cc);
    the current continuation handy. */
 int cc_swap(struct continuation *from, struct continuation *to);
 
-#define offset_of(type, member) ((unsigned long)(&((type *)0)->member))
-#define container_of(obj, type, member)                                 \
-        SPICE_ALIGNED_CAST(type *,                                      \
-                           (((char *)obj) - offset_of(type, member)))
-
 /*
  * Local variables:
  *  c-indent-level: 8
