@@ -34,6 +34,8 @@
 #include "channel-playback-priv.h"
 #include "spice-audio-priv.h"
 
+G_STATIC_ASSERT(sizeof(SpiceSessionClass) == sizeof(GObjectClass) + 12 * sizeof(gpointer));
+
 #if !defined(SOL_TCP) && defined(IPPROTO_TCP)
 #define SOL_TCP IPPROTO_TCP
 #endif
@@ -237,11 +239,11 @@ GType
 spice_image_compress_get_type (void)
 {
   static GType type = 0;
-  static volatile gsize type_volatile = 0;
+  static gsize type_once = 0;
 
-  if (g_once_init_enter(&type_volatile)) {
+  if (g_once_init_enter(&type_once)) {
     type = g_enum_register_static ("SpiceImageCompress", _spice_image_compress_values);
-    g_once_init_leave(&type_volatile, type);
+    g_once_init_leave(&type_once, type);
   }
 
   return type;
